@@ -1,26 +1,9 @@
-/* This file is part of Zanshin
-
-   Copyright 2015 Kevin Ottens <ervin@kde.org>
-
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.
+/*
+ * SPDX-FileCopyrightText: 2015 Kevin Ottens <ervin@kde.org>
+ SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
+
 #include "testlib/akonadifakedata.h"
 #include "akonadi/akonadimonitorinterface.h"
 #include "akonadi/akonadiserializer.h"
@@ -65,6 +48,19 @@ inline bool qCompare(const Akonadi::Item &left, const Akonadi::Item &right,
 
 }
 
+namespace
+{
+    template<typename T>
+    QSet<T> listToSet(const QVector<T> &list)
+    {
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
+        return list.toList().toSet();
+#else
+        return {list.cbegin(), list.cend()};
+#endif
+    }
+}
+
 class AkonadiFakeDataTest : public QObject
 {
     Q_OBJECT
@@ -106,7 +102,7 @@ private slots:
         data.createCollection(c2);
 
         // THEN
-        QCOMPARE(data.collections().toList().toSet(), colSet);
+        QCOMPARE(listToSet(data.collections()), colSet);
         QCOMPARE(data.collection(c1.id()), c1);
         QCOMPARE(data.collection(c2.id()), c2);
 
@@ -183,7 +179,7 @@ private slots:
 
         // THEN
         QVERIFY(data.childCollections(c2.id()).isEmpty());
-        QCOMPARE(data.childCollections(c1.id()).toList().toSet(), colSet);
+        QCOMPARE(listToSet(data.childCollections(c1.id())), colSet);
     }
 
     void shouldReparentCollectionsOnModify()
@@ -393,7 +389,7 @@ private slots:
         QCOMPARE(data.contextItems("ctx-1").at(0), i1);
         QVERIFY(data.contextItems("ctx-2").isEmpty());
 
-        QCOMPARE(data.items().toList().toSet(), itemSet);
+        QCOMPARE(listToSet(data.items()), itemSet);
 
         QVERIFY(data.item(i1.id()).isValid());
         const auto item2 = data.item(i2.id());
@@ -427,7 +423,7 @@ private slots:
         data.createItem(i2);
 
         // THEN
-        QCOMPARE(data.items().toList().toSet(), itemSet);
+        QCOMPARE(listToSet(data.items()), itemSet);
         QCOMPARE(data.item(i1.id()), i1);
         QCOMPARE(data.item(i2.id()), i2);
 
